@@ -2,8 +2,6 @@ import { defineConfig } from 'astro/config';
 import starlight from '@astrojs/starlight';
 import tailwindcss from '@tailwindcss/vite';
 
-const isLocalPreview = process.env.npm_lifecycle_script === 'astro dev';
-
 // https://astro.build/config
 export default defineConfig({
   site: 'https://tanka.dev',
@@ -11,19 +9,6 @@ export default defineConfig({
   trailingSlash: 'always',
   integrations: [
     starlight({
-      head: [
-        // We need to set the base tag because Starlight doesn't add one by default.
-        // This is sensible given that when serving a docs webiste from a subdirectory the assumption is that there's
-        // "another" website you may want to be able to link to.
-        // However, in our case, we use the base path only for PR previews and the actual website is always served from the root.
-        // This will make sure that links in markdown files work correctly both in PR previews and the prod website.
-        {
-          tag: 'base',
-          attrs: {
-            href: `${isLocalPreview ? 'http://localhost:4321' : 'https://tanka.dev'}${process.env.PATH_PREFIX || ''}`,
-          },
-        },
-      ],
       title: 'Grafana Tanka',
       description:
         'Grafana Tanka is the robust configuration utility for your Kubernetes cluster, powered by the Jsonnet language.',
